@@ -29,20 +29,22 @@
 #
 
 """
-hyhyhy CLI
+hyhyhy - Presentation nano-framework.
+
+It's a tool for easily creating pure and 
+simple HTML5 presentations or websites...
 
 Usage:
   hyhyhy create
   hyhyhy build
   hyhyhy watch
   hyhyhy status
-  hyhyhy help
-  hyhyhy -h | --help
-  hyhyhy -V | --version
+  hyhyhy (-h | --help)
+  hyhyhy --version
 
 Options:
-  -h, --help             Help information.
-  -V, --version          Show version.
+  -h --help     Show this screen.
+  --version     Show version.
 """
 
 import os
@@ -54,11 +56,13 @@ from rjsmin import jsmin
 from rcssmin import cssmin
 from watchdog.events import FileSystemEventHandler
 from watchdog.observers import Observer
+from docopt import docopt
 
 from hyhyhy.collector import collector
 from hyhyhy.config import config
 from hyhyhy.middleware import (num, prf)
 
+
 class Cli:
 
     class FileChangeHandler(FileSystemEventHandler):
@@ -155,18 +159,21 @@ class Cli:
 def main():
     cli = Cli()
 
-    if len(sys.argv) == 2 and sys.argv[1] == 'build':
+    arguments = docopt(__doc__)
+
+    if arguments['build'] == True:
         cli.build()
-    elif len(sys.argv) == 2 and sys.argv[1] == 'watch':
+    if arguments['watch'] == True:
         cli.watch()
-    elif len(sys.argv) == 2 and sys.argv[1] == 'create':
+    if arguments['create'] == True:
         cli.create()
-    elif len(sys.argv) == 2 and sys.argv[1] == 'status':
+    if arguments['status'] == True:
         cli.status()
     else:
-        print (__doc__)
+        print(arguments)
 
 
 if __name__ == '__main__':
-    main()  
+    main() 
 
+ 
\ No newline at end of file
